bluemath\_tk.downloaders.copernicus package
===========================================

Submodules
----------

bluemath\_tk.downloaders.copernicus.copernicus\_downloader module
-----------------------------------------------------------------

.. automodule:: bluemath_tk.downloaders.copernicus.copernicus_downloader
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: bluemath_tk.downloaders.copernicus
   :members:
   :undoc-members:
   :show-inheritance:
